<h1>Store Locator</h1>

<script type="text/javascript" src="http://maps.googleapis.com/maps/api/js?sensor=true"></script>
<script src="//ajax.googleapis.com/ajax/libs/jquery/1.7.0/jquery.min.js" type="text/javascript"></script>

<div class="locations_search_fields">
    <form>
        <input type="text" id="locations_search_field" /> 
        <select id="distance_field">
            <option value="1">1 Mile</option>
            <option value="5">5 Miles</option>
            <option value="10">10 Miles</option>
            <option value="15">15 Miles</option>
            <option value="25" selected="selected">25 Miles</option>
            <option value="50">50 Miles</option>
            <option value="100">100 Miles</option>
        </select>
        <input type="submit" onClick="location_search(); return false;" value="Search" />
    </form>
</div>
<div id="map_canvas" lass="locations_map" style="width:600px; height:400px"></div>

<script type="text/javascript" src="{{ STATIC_URL }}store_locator/js/store_locator_map.js"></script>
<script type="text/javascript">
    var get_lat_long_url = "{{ get_lat_long_url }}";
    var get_locations_url = "{{ get_locations_url }}";
</script>

